@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import urllib
+from requests.compat import quote
 
-from url import ReaderUrl
+from .url import ReaderUrl
 
 class ItemsContainer(object):
     """
@@ -143,8 +143,8 @@ class Category(ItemsContainer):
 
     @staticmethod
     def urlQuote(string):
-        """Encode a string to utf-8 and encode it for urllib"""
-        return urllib.quote(string.encode("utf-8"))
+        """ Quote a string for being used in a HTTP URL """
+        return quote(string.encode("utf-8"))
 
 class BaseFeed(ItemsContainer):
     """
@@ -269,7 +269,7 @@ class Item(object):
         self.content = item.get('content', item.get('summary', {})).get('content', '')
         self.origin  = { 'title': '', 'url': ''}
         if 'crawlTimeMsec' in item:
-            self.time = int(item['crawlTimeMsec']) / 1000
+            self.time = int(item['crawlTimeMsec']) // 1000
         else:
             self.time = None
 
